@@ -33,13 +33,14 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundIndicator.__tablename__}')
 
-    def delete_fund_indicator_with_dt(self, date_list):
+    def delete_fund_indicator_with_dt(self, date, fund_list):
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 session.query(
                     FundIndicator
                 ).filter(
-                    FundIndicator.datetime.in_(date_list),
+                    FundIndicator.fund_id.in_(fund_list),
+                    FundIndicator.datetime == date,
                 ).delete(synchronize_session=False)
                 session.commit()
                 return True
