@@ -1488,7 +1488,9 @@ class PortfolioDataApi(metaclass=Singleton):
             else:
                 if year is None:
                     # 年度
-                    index_price_y = basic.data_resample_monthly_nav(index_price.bfill(),rule='12M')
+                    index_price_y = basic.data_resample_monthly_nav(index_price.bfill(),rule='Y')
+                    _df = index_price.iloc[[0]]
+                    index_price_y = index_price_y.append(_df).sort_index().drop_duplicates()
                     index_ret_year = index_price_y.pct_change(1).dropna()
                     td = index_ret_year.index
                     td = [str(i.year) for i in td]
