@@ -346,7 +346,8 @@ class FundIndicatorProcessor(object):
             df = pd.concat(self.fac_result)
             df = df[df.datetime.isin(update_dt_list)]
             df = df.drop_duplicates(subset=['datetime','fund_id'])
-            DerivedDataApi().delete_fund_indicator_with_dt(date_list=update_dt_list)
+            for date in df.datetime.unique():
+                DerivedDataApi().delete_fund_indicator_with_dt(date, df[df.datetime == date].fund_id.to_list())
             self._data_helper._upload_derived(df, FundIndicator.__table__.name)
         except Exception as e:
             print(e)
@@ -358,4 +359,4 @@ class FundIndicatorProcessor(object):
 
 if __name__ == '__main__':
     fip = FundIndicatorProcessor(DerivedDataHelper())
-    fip.process('20210528', '20210528')
+    fip.process('20210602', '20210602')
