@@ -889,13 +889,14 @@ class FOFInfo(FOFBase):
     __tablename__ = 'fof_info'
 
     fof_id = Column(CHAR(16), primary_key=True)             # 产品ID
+    desc_id = Column(CHAR(31))                              # 展示ID
     manager_id = Column(VARCHAR(32), primary_key=True)      # 管理端ID
     datetime = Column(CHAR(16))                             # 数据日期（以支持更新操作）
     fof_name = Column(TEXT, nullable=False)                 # 产品名称
     desc_name = Column(CHAR(31))                            # 简称
     admin = Column(TEXT)                                    # 管理人
-    established_date = Column(DATE, nullable=False)         # 成立日期
-    running_start_date = Column(DATE, nullable=False)       # 实际运作起始日期
+    established_date = Column(DATE)                         # 成立日期
+    running_start_date = Column(DATE)                       # 实际运作起始日期
     fof_status = Column(CHAR(16))                           # 申赎状态等
     subscription_fee = Column(TEXT)                         # 认购费率
     purchase_fee = Column(TEXT)                             # 申购费率
