@@ -6,11 +6,13 @@ import re
 import datetime
 from typing import Optional, List, Union, Dict
 from .base import Factor
+from .calculator import Calculator
 from .utils import _START_DATE
 from ...data.manager import DataManager
 from ...data.manager.fund_info_filter import fund_info_update, get_conv_funds, filter_fund_info, active_fund_info as get_active_fund_info
 from ...data.struct import AssetTimeSpan
 from ...constant import FundFactorType
+
 class FundInfo(Factor):
 
     def __init__(self):
@@ -28,6 +30,7 @@ class InMarketFundInfo(Factor):
     def calc(self):#TODO
         self._factor = DataManager.basic_data(func_name='get_fund_status').drop(columns=['_update_time'], errors='ignore')
         self._factor = self._factor[~self._factor['trade_status'].isnull()]
+        self._factor = self._factor[~((self._factor.redem_status == '正常赎回') & (self._factor.purch_status == '正常申购'))]
         
 class CloseFundInfo(Factor):
 
@@ -144,7 +147,7 @@ class IndexCloseDaily(Factor):
     def calc(self):
         self._factor = DataManager.basic_data(func_name='get_index_price_dt', start_date=_START_DATE, columns=['close']).drop(columns=['_update_time'], errors='ignore')
         self._factor = self._factor.pivot(index='datetime',columns='index_id',values='close')
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())##
 
 class IndexRetDaily(Factor): # based on index_close_daily
 
@@ -157,7 +160,7 @@ class IndexRetDaily(Factor): # based on index_close_daily
         self._factor = IndexCloseDaily().get()
         self._factor = np.log(self._factor).diff(1)
         self._factor = self._factor.replace(np.Inf,np.nan).replace(-np.Inf,np.nan)
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())
 
 class IndexRetWeekly(Factor): # based on IndexRetDaily
 
@@ -167,7 +170,7 @@ class IndexRetWeekly(Factor): # based on IndexRetDaily
 
     def calc(self):
         self._factor = IndexRetDaily().get()
-        self._factor = self.data_resample_weekly_ret(self._factor).dropna(axis=0, how='all')
+        self._factor = Calculator.data_resample_weekly_ret(self._factor).dropna(axis=0, how='all')
 
 class IndexRetMonthly(Factor): # based on IndexRetDaily
 
@@ -177,7 +180,7 @@ class IndexRetMonthly(Factor): # based on IndexRetDaily
 
     def calc(self):
         self._factor = IndexRetDaily().get()
-        self._factor = self.data_resample_monthly_ret(self._factor).dropna(axis=0, how='all')
+        self._factor = Calculator.data_resample_monthly_ret(self._factor).dropna(axis=0, how='all')
 
 class FundNavDaily(Factor):
 
@@ -188,7 +191,7 @@ class FundNavDaily(Factor):
     def calc(self):
         self._factor = DataManager.basic_data(func_name='get_fund_nav_with_date', start_date=_START_DATE).drop(columns=['_update_time'], errors='ignore')
         self._factor = self._factor.pivot(index='datetime',columns='fund_id',values='adjusted_net_value')
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())
 
 class FundRetDaily(Factor): # based on FundNavDaily
 
@@ -200,7 +203,7 @@ class FundRetDaily(Factor): # based on FundNavDaily
     def calc(self):
         self._factor = FundNavDaily().get()
         self._factor = np.log(self._factor).diff(1)
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())
 
 class FundSize(Factor):
 
@@ -211,7 +214,7 @@ class FundSize(Factor):
     def calc(self):
         self._factor = DataManager.basic_data(func_name='get_fund_size_range', start_date=_START_DATE).drop(columns=['_update_time'], errors='ignore')
         self._factor = self._factor.pivot(index='datetime',columns='fund_id',values='size')
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())
 
 class FundSizeCombine(Factor): # based on FundSize
 
@@ -229,7 +232,7 @@ class FundSizeCombine(Factor): # based on FundSize
         fund_id_df = fund_info.set_index('trim_name')[['fund_id']]
         self._factor = fund_size.T.join(trim_name_df).groupby('trim_name').sum()
         self._factor = self._factor.join(fund_id_df).set_index('fund_id').T
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())
 
 class FundCompanyHold(Factor):
 
@@ -240,7 +243,7 @@ class FundCompanyHold(Factor):
     def calc(self):
         self._factor = DataManager.basic_data(func_name='get_fund_company_hold', start_date=_START_DATE).drop(columns=['_update_time'], errors='ignore')
         self._factor = self._factor.pivot(index='datetime',columns='fund_id',values='institution_holds')
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())
 
 class FundRetDailyModify(Factor): # based on fund_info fund_ret_daily
 
@@ -255,14 +258,14 @@ class FundRetDailyModify(Factor): # based on fund_info fund_ret_daily
         fund_ret = FundRetDaily().get()
         _res = []
         _fund_ret_columns = fund_ret.columns.tolist()
-        for fund_type, filter_ratio in self.FILTER_NAV_RATIO.items():
-            _info_fund_list = fund_info[fund_info['wind_class_2'].isin(self.FUND_CLASSIFIER[fund_type])].fund_id.tolist()
+        for fund_type, filter_ratio in Calculator.FILTER_NAV_RATIO.items():
+            _info_fund_list = fund_info[fund_info['wind_class_2'].isin(Calculator.FUND_CLASSIFIER[fund_type])].fund_id.tolist()
             _fund_list = list(set(_info_fund_list).intersection(_fund_ret_columns))
             _fund_ret = fund_ret[_fund_list].copy()
             _fund_ret[_fund_ret > filter_ratio] = 0
             _res.append(_fund_ret)
         self._factor = pd.concat(_res,axis=1)
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())
         self._factor = self._factor.loc[:,~self._factor.columns.duplicated()].copy()
 
 class FundInfoAsset(Factor):
@@ -304,7 +307,7 @@ class FundRetWeeklyModify(Factor): # based on FundRetDailyModify
 
     def calc(self):
         self._factor = FundRetDailyModify().get()
-        self._factor = self.data_resample_weekly_ret(self._factor).dropna(axis=0, how='all')
+        self._factor = Calculator.data_resample_weekly_ret(self._factor).dropna(axis=0, how='all')
 
 class FundRetMonthlyModify(Factor): # based on FundRetDailyModify
 
@@ -314,7 +317,7 @@ class FundRetMonthlyModify(Factor): # based on FundRetDailyModify
 
     def calc(self):
         self._factor = FundRetDailyModify().get()
-        self._factor = self.data_resample_monthly_ret(self._factor).dropna(axis=0, how='all')
+        self._factor = Calculator.data_resample_monthly_ret(self._factor).dropna(axis=0, how='all')
 
 class FundNavDailyModify(Factor): # based on fund_ret_daily_modify
 
@@ -326,7 +329,7 @@ class FundNavDailyModify(Factor): # based on fund_ret_daily_modify
     def calc(self):
         self._factor = FundRetDailyModify().get()
         self._factor = np.exp(self._factor.cumsum())
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())
 
 class FundNavWeeklyModify(Factor): # based on FundNavDailyModify
 
@@ -336,7 +339,7 @@ class FundNavWeeklyModify(Factor): # based on FundNavDailyModify
 
     def calc(self):
         self._factor = FundNavDailyModify().get()
-        self._factor = self.data_resample_weekly_nav(self._factor).dropna(axis=0, how='all')
+        self._factor = Calculator.data_resample_weekly_nav(self._factor).dropna(axis=0, how='all')
 
 class FundNavMonthlyModify(Factor): # based on FundNavDailyModify
 
@@ -346,7 +349,7 @@ class FundNavMonthlyModify(Factor): # based on FundNavDailyModify
 
     def calc(self):
         self._factor = FundNavDailyModify().get()
-        self._factor = self.data_resample_monthly_nav(self._factor).dropna(axis=0, how='all')
+        self._factor = Calculator.data_resample_monthly_nav(self._factor).dropna(axis=0, how='all')
 
 class Macroeco(Factor):
 
@@ -357,7 +360,7 @@ class Macroeco(Factor):
     def calc(self):
         self._factor = DataManager.raw_data(func_name='get_em_macroeconomic_daily', codes=['EX_DR_RATIO']).drop(columns='_update_time')
         self._factor = self._factor.pivot_table(index='datetime', columns='codes', values='value')
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())
 
 class FundBenchmarkRet(Factor): # based on fund_benchmark_info macroeco index_close_daily fund_info fund_nav_daily fund_info
 
@@ -408,7 +411,7 @@ class FundBenchmarkRet(Factor): # based on fund_benchmark_info macroeco index_cl
                                 # print(f'[benchmark_return] Error: Data Missing: {row.fund_id} {index} {index_raw}')
                                 break
                             else:
-                                values.append(ra.iloc[1:] * 0.01 * weight / self.TRADING_DAYS_PER_YEAR)
+                                values.append(ra.iloc[1:] * 0.01 * weight / Calculator.TRADING_DAYS_PER_YEAR)
                     else:
                         if weight == -1:
                             # 表示我们无法解析公式
@@ -428,7 +431,7 @@ class FundBenchmarkRet(Factor): # based on fund_benchmark_info macroeco index_cl
                     if values or cons:
                         the_sum: float = sum(values)
                         if cons:
-                            the_sum += np.log(math.pow(1 + cons, 1 / self.TRADING_DAYS_PER_YEAR))
+                            the_sum += np.log(math.pow(1 + cons, 1 / Calculator.TRADING_DAYS_PER_YEAR))
                         benchmark_list[row.fund_id] = the_sum
         self._factor =  pd.DataFrame.from_dict(benchmark_list)
         benchmark_cols = self._factor.columns.tolist()
@@ -438,14 +441,14 @@ class FundBenchmarkRet(Factor): # based on fund_benchmark_info macroeco index_cl
             benchmark_id = fund_id
             if not benchmark_id in benchmark_cols:    
                 wind_class_2 = wind_class_2_dict[fund_id]
-                if wind_class_2 not in self.WIND_TYPE_DICT:
+                if wind_class_2 not in Calculator.WIND_TYPE_DICT:
                     continue
-                select_type = self.WIND_TYPE_DICT[wind_class_2]
-                index_price_i = index_price[self.REPLACE_DICT[select_type]].rename(benchmark_id)
+                select_type = Calculator.WIND_TYPE_DICT[wind_class_2]
+                index_price_i = index_price[Calculator.REPLACE_DICT[select_type]].rename(benchmark_id)
                 benchmark_ret = np.log(index_price_i).diff(1)
                 _res.append(benchmark_ret)
         self._factor = self._factor.join(pd.concat(_res,axis=1))
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())
         cols = self._factor.columns.tolist()
         cols = [i for i in cols if isinstance(i, str)]
         self._factor = self._factor[cols]
@@ -469,7 +472,7 @@ class FundBenchmarkPrice(Factor): # based on FundBenchmarkRet
     def calc(self):
         self._factor = FundBenchmarkRet().get()
         self._factor = np.exp(self._factor.cumsum())
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())
 
 class FundPersonalHold(Factor):
 
@@ -480,7 +483,7 @@ class FundPersonalHold(Factor):
     def calc(self):
         self._factor = DataManager.basic_data(func_name='get_history_fund_size', start_date=_START_DATE).drop(columns=['_update_time'], errors='ignore')
         self._factor = self._factor.pivot(index='datetime',columns='fund_id',values='personal_holds')
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
+        self._factor = Calculator.data_reindex_daily_trading_day(self._factor, TradingDay().get())
 
 '''
 import surfing.data.fund_fac.basic_factors_daily as basic
