@@ -4,6 +4,7 @@ import pandas as pd
 import numpy as np
 import math
 import statsmodels.api as sm
+from typing import Optional
 from statsmodels import regression
 from scipy.stats import gmean
 from functools import partial
@@ -949,7 +950,7 @@ class CalculatorBase:
                                 close_values:pd.core.series.Series,
                                 open_values:pd.core.series.Series,
                                 rate:float,
-                                limit_num:str):
+                                limit_num: Optional[str]):
 
         rate = rate / 100
         dates = pd.to_datetime(dates)
@@ -957,14 +958,18 @@ class CalculatorBase:
         assert len(dates) == len(close_values), 'date and port_values has different numbers'
         assert len(dates) == len(open_values), 'date and port_values has different numbers'
         df = pd.DataFrame({'close':close_values,'open':open_values}, index=dates).sort_index().dropna()
-        limit_num = int(limit_num.split('网上申购数量上限：')[1].split('手')[0])
+        if limit_num is not None:
+            limit_num = int(limit_num.split('网上申购数量上限：')[1].split('手')[0])
         trade_market = bond_id.split('.')[1]
         new_price = df.close[-1]
         total_ret = df.close[-1] / ipo_price - 1
         first_open = df.open[0]
         first_date_rate = df.close[0] / 100 - 1
         earn_per_stick = (first_open - ipo_price) * 10
-        earn_per_account = earn_per_stick * limit_num * rate
+        if limit_num is not None:
+            earn_per_account = earn_per_stick * limit_num * rate
+        else:
+            earn_per_account = np.nan
         res = {
             'bond_id':bond_id,
             'bond_name':bond_name,
