@@ -135,7 +135,7 @@ class MailAttachmentRetriever:
                                         real_name = f"{subject}_{encoding}.xlsx"
                                         file_path = os.path.join(self._dump_dir, real_name)
                                         try:
-                                            if df.shape[0] <= 2:
+                                            if df.shape[0] < 2:
                                                 df.to_excel(file_path, index=False)
                                             else:
                                                 df.to_excel(file_path, header=None, index=False)
@@ -160,4 +160,4 @@ if __name__ == '__main__':
         sys.exit(f'can not found enough params in env (e){e}')
 
     mar = MailAttachmentRetriever(email_data_dir, ['xls', 'xlsx', 'pdf'])
-    print(mar.get_excels(IMAP_SPType.IMAP_QQ, user_name, password, b'811'))
+    print(mar.get_excels(IMAP_SPType.IMAP_QQ, user_name, password, b'926'))
